@@ -20,7 +20,7 @@
 #define ARMA_NO_DEBUG
 #endif*/
 
-#ifdef SUPPORT_OPENMP
+#ifdef _OPENMP
    #include <omp.h>
 #else
    #define omp_get_max_threads() 0
